#!/usr/bin/env node

/* eslint-disable no-console */
"use strict";

var _kielbasa = require("./kielbasa.js");

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _commander = _interopRequireDefault(require("commander"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let stdin = '';

function handleAction(string = '', performAction) {
  const input = stdin || string;
  console.log(performAction(input));
}

function getVersion() {
  const pjsonPath = _path.default.join(__dirname, '..', 'package.json'); // Synchronous operations are okay in CLI tools,
  // as per no-sync rule documentation
  // eslint-disable-next-line no-sync


  const pjsonContent = _fs.default.readFileSync(pjsonPath, 'utf8');

  return JSON.parse(pjsonContent).version;
}

_commander.default.name('kielbasa').version(getVersion(), '-v, --version').option('-l, --language [string]', 'set the language. defaults to "en"', 'en');

_commander.default.command('camel-case [string]').alias('cam').description('convert a string to camel case').action(string => {
  handleAction(string, _kielbasa.getCamelCase);
});

_commander.default.command('kebab-case [string]').alias('keb').description('convert a string to kebab case').action(string => {
  handleAction(string, _kielbasa.getKebabCase);
});

_commander.default.command('lower-case [string]').alias('low').description('convert a string to lower case').action(string => {
  handleAction(string, _kielbasa.getLowerCase);
});

_commander.default.command('screaming-snake-case [string]').alias('scr').description('convert a string to screaming snake case').action(string => {
  handleAction(string, _kielbasa.getScreamingSnakeCase);
});

_commander.default.command('snake-case [string]').alias('sna').description('convert a string to snake case').action(string => {
  handleAction(string, _kielbasa.getSnakeCase);
});

_commander.default.command('start-case [string]').alias('sta').description('convert a string to start case').action(string => {
  handleAction(string, _kielbasa.getStartCase);
});

_commander.default.command('train-case [string]').alias('tra').description('convert a string to train case').action(string => {
  handleAction(string, _kielbasa.getTrainCase);
});

_commander.default.command('upper-case [string]').alias('upp').description('convert a string to upper case').action(string => {
  handleAction(string, _kielbasa.getUpperCase);
});

if (process.stdin.isTTY) {
  _commander.default.parse(process.argv);
} else {
  process.stdin.on('readable', function addChunkToStdin() {
    // Necessary for proper chunk reading
    // eslint-disable-next-line no-invalid-this
    const chunk = this.read();

    if (chunk !== null) {
      stdin += chunk;
    }
  });
  process.stdin.on('end', () => {
    stdin = stdin.replace(/\n$/, '');

    _commander.default.parse(process.argv);
  });
}
